@@ -8,16 +8,14 @@
 #include "youtubejob.h"
 #include <Accounts/Application>
 #include <Accounts/Manager>
-#include <KAccounts/core.h>
-#include <KAccounts/getcredentialsjob.h>
+#include <KAccounts/Core>
+#include <KAccounts/GetCredentialsJob>
 #include <KLocalizedString>
 #include <QDebug>
 #include <QJsonArray>
 #include <QJsonValue>
 #include <QStandardPaths>
 
-using namespace KAccounts;
-
 QDebug operator<<(QDebug s, const Accounts::Service &service)
 {
     s.nospace() << qPrintable(service.displayName()) << ',' << qPrintable(service.name()) << '\n';
@@ -48,7 +46,7 @@ void YoutubeJobComposite::start()
     // TODO: make async
     QByteArray accessToken;
     {
-        auto job = new GetCredentialsJob(id, this);
+        auto job = new KAccounts::GetCredentialsJob(id, this);
         bool b = job->exec();
         if (!b) {
             qWarning() << "Couldn't fetch credentials";
